@@ -81,7 +81,7 @@ RE_PATTERN_RESIZE = re.compile(r'\x1b\[48;(?P<height_chars>\d+);(?P<width_chars>
                                r';(?P<height_pixels>\d+);(?P<width_pixels>\d+)t')
 
 # DEC event pattern container
-DECEventPattern = functools.namedtuple("DEC_EVENT_PATTERN", ["mode", "pattern"])
+DECEventPattern = namedtuple("DECEventPattern", ["mode", "pattern"])
 
 # DEC event patterns - compiled regexes with metadata of the 'mode' that
 # triggered it, this prevents searching for bracketed paste or mouse modes
@@ -1079,7 +1079,6 @@ class Keystroke(str):
     def _mode_values(self) -> Optional[typing.Union[BracketedPasteEvent,
                                                     MouseSGREvent, MouseLegacyEvent, FocusEvent,
                                                     ResizeEvent]]:
-        # pylint: disable=too-many-return-statements
         """
         Return structured data for DEC private mode events (private API).
 
@@ -1181,10 +1180,12 @@ def get_keyboard_codes() -> Dict[int, str]:
     keycodes = OrderedDict(get_curses_keycodes())
     keycodes.update(CURSES_KEYCODE_OVERRIDE_MIXIN)
 
-    # merge in homemade KEY_TAB, KEY_KP_*, KEY_MENU added to our module space
+    # Merge in homemade KEY_TAB, KEY_KP_*, KEY_MENU added to our module space
     # Exclude *_PUA constants since they're internal implementation details
-    # that will be remapped via KITTY_PUA_KEYCODE_OVERRIDE_MIXIN
-    keycodes.update((k, v) for k, v in globals().items()
+    # that will be remapped via KITTY_PUA_KEYCODE_OVERRIDE_MIXIN.
+    # Make sure to copy globals() since other threads might create or
+    # destroy globals while we iterate.
+    keycodes.update((k, v) for k, v in globals().copy().items()
                     if k.startswith('KEY_') and not k.endswith('_PUA'))
 
     # Apply PUA keycode overrides to strip _PUA suffix from names
@@ -1263,9 +1264,9 @@ def get_keyboard_sequences(term: 'Terminal') -> typing.OrderedDict[str, int]:
     # This is for fast lookup matching of sequences, preferring
     # full-length sequence such as ('\x1b[D', KEY_LEFT)
     # over simple sequences such as ('\x1b', KEY_EXIT).
-    return OrderedDict((
+    return OrderedDict(
         (seq, sequence_map[seq]) for seq in sorted(
-            sequence_map.keys(), key=len, reverse=True)))
+            sequence_map.keys(), key=len, reverse=True))
 
 
 def get_leading_prefixes(sequences: typing.Iterable[str]) -> Set[str]:
@@ -2054,7 +2055,7 @@ KITTY_PUA_KEYCODE_OVERRIDE_MIXIN = (
 #: escape sequences.  This is too long for modern applications, so we set it to
 #: 350ms, or 0.35 seconds. It is still a bit conservative, for remote telnet or
 #: ssh servers, for example.
-DEFAULT_ESCDELAY = 0.35  # pylint: disable=invalid-name
+DEFAULT_ESCDELAY = 0.35
 
 
 def _reinit_escdelay() -> None:
